/*
    Copyright 2021-2022. Huawei Technologies Co., Ltd. All rights reserved.

    Licensed under the Apache License, Version 2.0 (the "License")
    you may not use this file except in compliance with the License.
    You may obtain a copy of the License at

        https://www.apache.org/licenses/LICENSE-2.0

    Unless required by applicable law or agreed to in writing, software
    distributed under the License is distributed on an "AS IS" BASIS,
    WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
    See the License for the specific language governing permissions and
    limitations under the License.
*/

part of huawei_gameservice;

/// A class that includes the information about a leaderboard
/// and the list of scores on the leaderboard.
class RankingScores {
  /// Leaderboard information.
  Ranking? ranking;

  /// All scores on a leaderboard.
  List<RankingScore>? rankingScores;

  RankingScores({
    this.ranking,
    this.rankingScores,
  });

  factory RankingScores.fromMap(Map<dynamic, dynamic> map) {
    return RankingScores(
      ranking: map['ranking'] != null ? Ranking.fromMap(map['ranking']) : null,
      rankingScores: map['rankingScores'] != null
          ? List<RankingScore>.from(
              map['rankingScores'].map(
                (dynamic e) => RankingScore.fromMap(e),
              ),
            )
          : null,
    );
  }

  Map<String, dynamic> toMap() {
    return <String, dynamic>{
      'ranking': ranking?.toMap(),
      'rankingScores': rankingScores
          ?.map((RankingScore rankingScore) => rankingScore.toMap())
          .toList(),
    };
  }

  @override
  String toString() {
    return '$RankingScores('
        'ranking: $ranking, '
        'rankingScores: $rankingScores)';
  }
}
